@@ -9,127 +9,114 @@
 #include "fileviewsvnpluginsettings.h"
 
 #include <KLocalizedString>
-#include <KShell>
 #include <KPluginFactory>
+#include <KShell>
 
+#include <KConfigGroup>
+#include <KWindowConfig>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QDir>
+#include <QHeaderView>
 #include <QLabel>
+#include <QListWidget>
 #include <QPlainTextEdit>
 #include <QProcess>
 #include <QPushButton>
 #include <QString>
 #include <QStringList>
+#include <QTableWidget>
 #include <QTextStream>
 #include <QVBoxLayout>
-#include <QListWidget>
-#include <KConfigGroup>
-#include <KWindowConfig>
 #include <QWindow>
-#include <QTableWidget>
-#include <QHeaderView>
 
+#include "svncheckoutdialog.h"
+#include "svncleanupdialog.h"
 #include "svncommitdialog.h"
 #include "svnlogdialog.h"
-#include "svncheckoutdialog.h"
 #include "svnprogressdialog.h"
-#include "svncleanupdialog.h"
 
 #include "svncommands.h"
 
 K_PLUGIN_CLASS_WITH_JSON(FileViewSvnPlugin, "fileviewsvnplugin.json")
 
-FileViewSvnPlugin::FileViewSvnPlugin(QObject* parent, const QList<QVariant>& args) :
-    KVersionControlPlugin(parent),
-    m_pendingOperation(false),
-    m_versionInfoHash(),
-    m_updateAction(nullptr),
-    m_showLocalChangesAction(nullptr),
-    m_commitAction(nullptr),
-    m_addAction(nullptr),
-    m_removeAction(nullptr),
-    m_showUpdatesAction(nullptr),
-    m_logAction(nullptr),
-    m_checkoutAction(nullptr),
-    m_cleanupAction(nullptr),
-    m_command(),
-    m_arguments(),
-    m_errorMsg(),
-    m_operationCompletedMsg(),
-    m_contextDir(),
-    m_contextItems(),
-    m_process(),
-    m_tempFile()
+FileViewSvnPlugin::FileViewSvnPlugin(QObject *parent, const QList<QVariant> &args)
+    : KVersionControlPlugin(parent)
+    , m_pendingOperation(false)
+    , m_versionInfoHash()
+    , m_updateAction(nullptr)
+    , m_showLocalChangesAction(nullptr)
+    , m_commitAction(nullptr)
+    , m_addAction(nullptr)
+    , m_removeAction(nullptr)
+    , m_showUpdatesAction(nullptr)
+    , m_logAction(nullptr)
+    , m_checkoutAction(nullptr)
+    , m_cleanupAction(nullptr)
+    , m_command()
+    , m_arguments()
+    , m_errorMsg()
+    , m_operationCompletedMsg()
+    , m_contextDir()
+    , m_contextItems()
+    , m_process()
+    , m_tempFile()
 {
     Q_UNUSED(args);
 
-    m_parentWidget = qobject_cast<QWidget*>(parent);
+    m_parentWidget = qobject_cast<QWidget *>(parent);
 
     m_updateAction = new QAction(this);
     m_updateAction->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     m_updateAction->setText(i18nc("@item:inmenu", "SVN Update"));
-    connect(m_updateAction, &QAction::triggered,
-            this, &FileViewSvnPlugin::updateFiles);
+    connect(m_updateAction, &QAction::triggered, this, &FileViewSvnPlugin::updateFiles);
 
     m_showLocalChangesAction = new QAction(this);
     m_showLocalChangesAction->setIcon(QIcon::fromTheme(QStringLiteral("view-split-left-right")));
     m_showLocalChangesAction->setText(i18nc("@item:inmenu", "Show Local SVN Changes"));
-    connect(m_showLocalChangesAction, &QAction::triggered,
-            this, &FileViewSvnPlugin::showLocalChanges);
+    connect(m_showLocalChangesAction, &QAction::triggered, this, &FileViewSvnPlugin::showLocalChanges);
 
     m_commitAction = new QAction(this);
     m_commitAction->setIcon(QIcon::fromTheme(QStringLiteral("vcs-commit")));
     m_commitAction->setText(i18nc("@item:inmenu", "SVN Commit..."));
-    connect(m_commitAction, &QAction::triggered,
-            this, &FileViewSvnPlugin::commitDialog);
+    connect(m_commitAction, &QAction::triggered, this, &FileViewSvnPlugin::commitDialog);
 
     m_addAction = new QAction(this);
     m_addAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     m_addAction->setText(i18nc("@item:inmenu", "SVN Add"));
-    connect(m_addAction, &QAction::triggered,
-            this, QOverload<>::of(&FileViewSvnPlugin::addFiles));
+    connect(m_addAction, &QAction::triggered, this, QOverload<>::of(&FileViewSvnPlugin::addFiles));
 
     m_removeAction = new QAction(this);
     m_removeAction->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
     m_removeAction->setText(i18nc("@item:inmenu", "SVN Delete"));
-    connect(m_removeAction, &QAction::triggered,
-            this, &FileViewSvnPlugin::removeFiles);
+    connect(m_removeAction, &QAction::triggered, this, &FileViewSvnPlugin::removeFiles);
 
     m_revertAction = new QAction(this);
     m_revertAction->setIcon(QIcon::fromTheme(QStringLiteral("document-revert")));
     m_revertAction->setText(i18nc("@item:inmenu", "SVN Revert"));
-    connect(m_revertAction, &QAction::triggered,
-            this, QOverload<>::of(&FileViewSvnPlugin::revertFiles));
+    connect(m_revertAction, &QAction::triggered, this, QOverload<>::of(&FileViewSvnPlugin::revertFiles));
 
     m_showUpdatesAction = new QAction(this);
     m_showUpdatesAction->setCheckable(true);
     m_showUpdatesAction->setText(i18nc("@item:inmenu", "Show SVN Updates"));
     m_showUpdatesAction->setChecked(FileViewSvnPluginSettings::showUpdates());
-    connect(m_showUpdatesAction, &QAction::toggled,
-            this, &FileViewSvnPlugin::slotShowUpdatesToggled);
-    connect(this, &FileViewSvnPlugin::setShowUpdatesChecked,
-            m_showUpdatesAction, &QAction::setChecked);
+    connect(m_showUpdatesAction, &QAction::toggled, this, &FileViewSvnPlugin::slotShowUpdatesToggled);
+    connect(this, &FileViewSvnPlugin::setShowUpdatesChecked, m_showUpdatesAction, &QAction::setChecked);
 
     m_logAction = new QAction(this);
     m_logAction->setText(i18nc("@action:inmenu", "SVN Log..."));
-    connect(m_logAction, &QAction::triggered,
-            this, &FileViewSvnPlugin::logDialog);
+    connect(m_logAction, &QAction::triggered, this, &FileViewSvnPlugin::logDialog);
 
     m_checkoutAction = new QAction(this);
     m_checkoutAction->setText(i18nc("@action:inmenu", "SVN Checkout..."));
-    connect(m_checkoutAction, &QAction::triggered,
-            this, &FileViewSvnPlugin::checkoutDialog);
+    connect(m_checkoutAction, &QAction::triggered, this, &FileViewSvnPlugin::checkoutDialog);
 
     m_cleanupAction = new QAction(this);
     m_cleanupAction->setText(i18nc("@action:inmenu", "SVN Cleanup..."));
-    connect(m_cleanupAction, &QAction::triggered,
-            this, &FileViewSvnPlugin::cleanupDialog);
+    connect(m_cleanupAction, &QAction::triggered, this, &FileViewSvnPlugin::cleanupDialog);
 
-    connect(&m_process, &QProcess::finished,
-            this, &FileViewSvnPlugin::slotOperationCompleted);
-    connect(&m_process, &QProcess::errorOccurred,
-            this, &FileViewSvnPlugin::slotOperationError);
+    connect(&m_process, &QProcess::finished, this, &FileViewSvnPlugin::slotOperationCompleted);
+    connect(&m_process, &QProcess::errorOccurred, this, &FileViewSvnPlugin::slotOperationError);
 }
 
 FileViewSvnPlugin::~FileViewSvnPlugin()
@@ -141,20 +128,23 @@ QString FileViewSvnPlugin::fileName() const
     return QLatin1String(".svn");
 }
 
-QString FileViewSvnPlugin::localRepositoryRoot(const QString& directory) const
+QString FileViewSvnPlugin::localRepositoryRoot(const QString &directory) const
 {
     QProcess process;
     process.setWorkingDirectory(directory);
-    process.start(QStringLiteral("svn"), {
-        QStringLiteral("info"), QStringLiteral("--show-item"), QStringLiteral("wc-root"),
-    });
+    process.start(QStringLiteral("svn"),
+                  {
+                      QStringLiteral("info"),
+                      QStringLiteral("--show-item"),
+                      QStringLiteral("wc-root"),
+                  });
     if (process.waitForReadyRead(100) && process.exitCode() == 0) {
         return QString::fromUtf8(process.readAll().chopped(1));
     }
     return QString();
 }
 
-bool FileViewSvnPlugin::beginRetrieval(const QString& directory)
+bool FileViewSvnPlugin::beginRetrieval(const QString &directory)
 {
     Q_ASSERT(directory.endsWith(QLatin1Char('/')));
 
@@ -181,18 +171,30 @@ bool FileViewSvnPlugin::beginRetrieval(const QString& directory)
     process.start(QLatin1String("svn"), arguments);
     while (process.waitForReadyRead()) {
         char buffer[1024];
-        while (process.readLine(buffer, sizeof(buffer)) > 0)  {
+        while (process.readLine(buffer, sizeof(buffer)) > 0) {
             ItemVersion version = NormalVersion;
             QString filePath = QString::fromLocal8Bit(buffer);
 
             switch (buffer[0]) {
             case 'I':
-            case '?': version = UnversionedVersion; break;
-            case 'M': version = LocallyModifiedVersion; break;
-            case 'A': version = AddedVersion; break;
-            case 'D': version = RemovedVersion; break;
-            case 'C': version = ConflictingVersion; break;
-            case '!': version = MissingVersion; break;
+            case '?':
+                version = UnversionedVersion;
+                break;
+            case 'M':
+                version = LocallyModifiedVersion;
+                break;
+            case 'A':
+                version = AddedVersion;
+                break;
+            case 'D':
+                version = RemovedVersion;
+                break;
+            case 'C':
+                version = ConflictingVersion;
+                break;
+            case '!':
+                version = MissingVersion;
+                break;
             default:
                 if (filePath.contains(QLatin1Char('*'))) {
                     version = UpdateRequiredVersion;
@@ -219,8 +221,9 @@ bool FileViewSvnPlugin::beginRetrieval(const QString& directory)
     if ((process.exitCode() != 0 || process.exitStatus() != QProcess::NormalExit)) {
         if (FileViewSvnPluginSettings::showUpdates()) {
             // Network update failed. Unset ShowUpdates option, which triggers a refresh
-            Q_EMIT infoMessage(i18nc("@info:status", "SVN status update failed. Disabling Option "
-                                   "\"Show SVN Updates\"."));
+            Q_EMIT infoMessage(i18nc("@info:status",
+                                     "SVN status update failed. Disabling Option "
+                                     "\"Show SVN Updates\"."));
             Q_EMIT setShowUpdatesChecked(false);
             // this is no fail, we just try again differently
             // furthermore returning false shows an error message that would override our info
@@ -238,7 +241,7 @@ void FileViewSvnPlugin::endRetrieval()
     Q_EMIT versionInfoUpdated();
 }
 
-KVersionControlPlugin::ItemVersion FileViewSvnPlugin::itemVersion(const KFileItem& item) const
+KVersionControlPlugin::ItemVersion FileViewSvnPlugin::itemVersion(const KFileItem &item) const
 {
     const QString itemUrl = item.localPath();
     if (m_versionInfoHash.contains(itemUrl)) {
@@ -276,7 +279,7 @@ KVersionControlPlugin::ItemVersion FileViewSvnPlugin::itemVersion(const KFileIte
     return NormalVersion;
 }
 
-QList<QAction*> FileViewSvnPlugin::versionControlActions(const KFileItemList& items) const
+QList<QAction *> FileViewSvnPlugin::versionControlActions(const KFileItemList &items) const
 {
     // Special case: if any item is in unversioned directory we shouldn't add any actions because
     // we can do nothing with this item.
@@ -290,7 +293,7 @@ QList<QAction*> FileViewSvnPlugin::versionControlActions(const KFileItemList& it
         return directoryActions(items.first());
     }
 
-    for (const KFileItem& item : items) {
+    for (const KFileItem &item : items) {
         m_contextItems.append(item);
     }
     m_contextDir.clear();
@@ -302,21 +305,21 @@ QList<QAction*> FileViewSvnPlugin::versionControlActions(const KFileItemList& it
         const int itemsCount = items.count();
         int versionedCount = 0;
         int editingCount = 0;
-        for (const KFileItem& item : items) {
+        for (const KFileItem &item : items) {
             const ItemVersion version = itemVersion(item);
             if (version != UnversionedVersion) {
                 ++versionedCount;
             }
 
             switch (version) {
-                case LocallyModifiedVersion:
-                case ConflictingVersion:
-                case AddedVersion:
-                case RemovedVersion:
-                    ++editingCount;
-                    break;
-                default:
-                    break;
+            case LocallyModifiedVersion:
+            case ConflictingVersion:
+            case AddedVersion:
+            case RemovedVersion:
+                ++editingCount;
+                break;
+            default:
+                break;
             }
         }
         m_commitAction->setEnabled(editingCount > 0);
@@ -331,7 +334,7 @@ QList<QAction*> FileViewSvnPlugin::versionControlActions(const KFileItemList& it
     }
     m_updateAction->setEnabled(noPendingOperation);
 
-    QList<QAction*> actions;
+    QList<QAction *> actions;
     actions.append(m_updateAction);
     actions.append(m_commitAction);
     actions.append(m_addAction);
@@ -341,7 +344,7 @@ QList<QAction*> FileViewSvnPlugin::versionControlActions(const KFileItemList& it
     return actions;
 }
 
-QList<QAction*> FileViewSvnPlugin::outOfVersionControlActions(const KFileItemList& items) const
+QList<QAction *> FileViewSvnPlugin::outOfVersionControlActions(const KFileItemList &items) const
 {
     // Only for a single directory.
     if (items.count() != 1 || !items.first().isDir()) {
@@ -350,7 +353,7 @@ QList<QAction*> FileViewSvnPlugin::outOfVersionControlActions(const KFileItemLis
 
     m_contextDir = items.first().localPath();
 
-    return QList<QAction*>{} << m_checkoutAction;
+    return QList<QAction *>{} << m_checkoutAction;
 }
 
 void FileViewSvnPlugin::updateFiles()
@@ -358,7 +361,8 @@ void FileViewSvnPlugin::updateFiles()
     SvnProgressDialog *progressDialog = new SvnProgressDialog(i18nc("@title:window", "SVN Update"), m_contextDir, m_parentWidget);
     progressDialog->connectToProcess(&m_process);
 
-    execSvnCommand(QLatin1String("update"), QStringList(),
+    execSvnCommand(QLatin1String("update"),
+                   QStringList(),
                    i18nc("@info:status", "Updating SVN repository..."),
                    i18nc("@info:status", "Update of SVN repository failed."),
                    i18nc("@info:status", "Updated SVN repository."));
@@ -381,26 +385,14 @@ void FileViewSvnPlugin::showLocalChanges()
 
     QProcess process;
     process.setStandardOutputFile(file->fileName());
-    process.start(
-        QLatin1String("svn"),
-        QStringList {
-            QLatin1String("diff"),
-            QLatin1String("--git"),
-            m_contextDir
-        }
-    );
+    process.start(QLatin1String("svn"), QStringList{QLatin1String("diff"), QLatin1String("--git"), m_contextDir});
     if (!process.waitForFinished() || process.exitCode() != 0) {
         Q_EMIT errorMessage(i18nc("@info:status", "Could not show local SVN changes: svn diff failed."));
         file->deleteLater();
         return;
     }
 
-    const bool started = QProcess::startDetached(
-        QLatin1String("kompare"),
-        QStringList {
-            file->fileName()
-        }
-    );
+    const bool started = QProcess::startDetached(QLatin1String("kompare"), QStringList{file->fileName()});
     if (!started) {
         Q_EMIT errorMessage(i18nc("@info:status", "Could not show local SVN changes: could not start kompare."));
         file->deleteLater();
@@ -422,9 +414,9 @@ void FileViewSvnPlugin::commitDialog()
 
     connect(this, &FileViewSvnPlugin::versionInfoUpdated, svnCommitDialog, &SvnCommitDialog::refreshChangesList);
 
-    connect(svnCommitDialog, &SvnCommitDialog::revertFiles, this, QOverload<const QStringList&>::of(&FileViewSvnPlugin::revertFiles));
-    connect(svnCommitDialog, &SvnCommitDialog::diffFile, this, QOverload<const QString&>::of(&FileViewSvnPlugin::diffFile));
-    connect(svnCommitDialog, &SvnCommitDialog::addFiles, this, QOverload<const QStringList&>::of(&FileViewSvnPlugin::addFiles));
+    connect(svnCommitDialog, &SvnCommitDialog::revertFiles, this, QOverload<const QStringList &>::of(&FileViewSvnPlugin::revertFiles));
+    connect(svnCommitDialog, &SvnCommitDialog::diffFile, this, QOverload<const QString &>::of(&FileViewSvnPlugin::diffFile));
+    connect(svnCommitDialog, &SvnCommitDialog::addFiles, this, QOverload<const QStringList &>::of(&FileViewSvnPlugin::addFiles));
     connect(svnCommitDialog, &SvnCommitDialog::commit, this, &FileViewSvnPlugin::commitFiles);
 
     svnCommitDialog->setAttribute(Qt::WA_DeleteOnClose);
@@ -433,7 +425,8 @@ void FileViewSvnPlugin::commitDialog()
 
 void FileViewSvnPlugin::addFiles()
 {
-    execSvnCommand(QLatin1String("add"), QStringList(),
+    execSvnCommand(QLatin1String("add"),
+                   QStringList(),
                    i18nc("@info:status", "Adding files to SVN repository..."),
                    i18nc("@info:status", "Adding of files to SVN repository failed."),
                    i18nc("@info:status", "Added files to SVN repository."));
@@ -441,7 +434,8 @@ void FileViewSvnPlugin::addFiles()
 
 void FileViewSvnPlugin::removeFiles()
 {
-    execSvnCommand(QLatin1String("remove"), QStringList(),
+    execSvnCommand(QLatin1String("remove"),
+                   QStringList(),
                    i18nc("@info:status", "Removing files from SVN repository..."),
                    i18nc("@info:status", "Removing of files from SVN repository failed."),
                    i18nc("@info:status", "Removed files from SVN repository."));
@@ -461,13 +455,14 @@ void FileViewSvnPlugin::revertFiles()
         arguments << QLatin1String("--depth") << QLatin1String("infinity");
         root = m_contextDir;
     } else {
-        root = SvnCommands::localRoot( m_contextItems.last().localPath() );
+        root = SvnCommands::localRoot(m_contextItems.last().localPath());
     }
 
     SvnProgressDialog *progressDialog = new SvnProgressDialog(i18nc("@title:window", "SVN Revert"), root, m_parentWidget);
     progressDialog->connectToProcess(&m_process);
 
-    execSvnCommand(QStringLiteral("revert"), arguments,
+    execSvnCommand(QStringLiteral("revert"),
+                   arguments,
                    i18nc("@info:status", "Reverting files from SVN repository..."),
                    i18nc("@info:status", "Reverting of files from SVN repository failed."),
                    i18nc("@info:status", "Reverted files from SVN repository."));
@@ -531,7 +526,7 @@ void FileViewSvnPlugin::slotOperationError()
 
 void FileViewSvnPlugin::slotShowUpdatesToggled(bool checked)
 {
-    FileViewSvnPluginSettings* settings = FileViewSvnPluginSettings::self();
+    FileViewSvnPluginSettings *settings = FileViewSvnPluginSettings::self();
     Q_ASSERT(settings != nullptr);
     settings->setShowUpdates(checked);
     settings->save();
@@ -539,7 +534,7 @@ void FileViewSvnPlugin::slotShowUpdatesToggled(bool checked)
     Q_EMIT itemVersionsChanged();
 }
 
-void FileViewSvnPlugin::revertFiles(const QStringList& filesPath)
+void FileViewSvnPlugin::revertFiles(const QStringList &filesPath)
 {
     if (filesPath.empty()) {
         return;
@@ -553,13 +548,14 @@ void FileViewSvnPlugin::revertFiles(const QStringList& filesPath)
     SvnProgressDialog *progressDialog = new SvnProgressDialog(i18nc("@title:window", "SVN Revert"), SvnCommands::localRoot(filesPath.first()), m_parentWidget);
     progressDialog->connectToProcess(&m_process);
 
-    execSvnCommand(QLatin1String("revert"), QStringList() << filesPath,
+    execSvnCommand(QLatin1String("revert"),
+                   QStringList() << filesPath,
                    i18nc("@info:status", "Reverting changes to file..."),
                    i18nc("@info:status", "Revert file failed."),
                    i18nc("@info:status", "File reverted."));
 }
 
-void FileViewSvnPlugin::diffFile(const QString& filePath)
+void FileViewSvnPlugin::diffFile(const QString &filePath)
 {
     // For a diff we will export last known file local revision from a remote and compare. We will
     // not use basic SVN action 'svn diff --extensions -U<lines> <fileName>' because we should count
@@ -569,7 +565,7 @@ void FileViewSvnPlugin::diffFile(const QString& filePath)
     diffAgainstWorkingCopy(filePath, SvnCommands::localRevision(filePath));
 }
 
-void FileViewSvnPlugin::diffAgainstWorkingCopy(const QString& localFilePath, ulong rev)
+void FileViewSvnPlugin::diffAgainstWorkingCopy(const QString &localFilePath, ulong rev)
 {
     QTemporaryFile *file = new QTemporaryFile(this);
     if (!SvnCommands::exportFile(QUrl::fromLocalFile(localFilePath), rev, file)) {
@@ -578,20 +574,14 @@ void FileViewSvnPlugin::diffAgainstWorkingCopy(const QString& localFilePath, ulo
         return;
     }
 
-    const bool started = QProcess::startDetached(
-        QLatin1String("kompare"),
-        QStringList {
-            file->fileName(),
-            localFilePath
-        }
-    );
+    const bool started = QProcess::startDetached(QLatin1String("kompare"), QStringList{file->fileName(), localFilePath});
     if (!started) {
         Q_EMIT errorMessage(i18nc("@info:status", "Could not show local SVN changes: could not start kompare."));
         file->deleteLater();
     }
 }
 
-void FileViewSvnPlugin::diffBetweenRevs(const QString& remoteFilePath, ulong rev1, ulong rev2)
+void FileViewSvnPlugin::diffBetweenRevs(const QString &remoteFilePath, ulong rev1, ulong rev2)
 {
     QTemporaryFile *file1 = new QTemporaryFile(this);
     QTemporaryFile *file2 = new QTemporaryFile(this);
@@ -607,13 +597,7 @@ void FileViewSvnPlugin::diffBetweenRevs(const QString& remoteFilePath, ulong rev
         return;
     }
 
-    const bool started = QProcess::startDetached(
-        QLatin1String("kompare"),
-        QStringList {
-            file2->fileName(),
-            file1->fileName()
-        }
-    );
+    const bool started = QProcess::startDetached(QLatin1String("kompare"), QStringList{file2->fileName(), file1->fileName()});
     if (!started) {
         Q_EMIT errorMessage(i18nc("@info:status", "Could not show local SVN changes: could not start kompare."));
         file1->deleteLater();
@@ -621,7 +605,7 @@ void FileViewSvnPlugin::diffBetweenRevs(const QString& remoteFilePath, ulong rev
     }
 }
 
-void FileViewSvnPlugin::addFiles(const QStringList& filesPath)
+void FileViewSvnPlugin::addFiles(const QStringList &filesPath)
 {
     for (const auto &i : std::as_const(filesPath)) {
         m_contextItems.append(KFileItem(QUrl::fromLocalFile(i)));
@@ -631,7 +615,7 @@ void FileViewSvnPlugin::addFiles(const QStringList& filesPath)
     addFiles();
 }
 
-void FileViewSvnPlugin::commitFiles(const QStringList& context, const QString& msg)
+void FileViewSvnPlugin::commitFiles(const QStringList &context, const QString &msg)
 {
     if (context.empty()) {
         return;
@@ -641,10 +625,12 @@ void FileViewSvnPlugin::commitFiles(const QStringList& context, const QString& m
     // that it can be read by the command "svn commit -F". The temporary
     // file must stay alive until slotOperationCompleted() is invoked and will
     // be destroyed when the version plugin is destructed.
-    if (!m_tempFile.open())  {
+    if (!m_tempFile.open()) {
         Q_EMIT errorMessage(i18nc("@info:status", "Commit of SVN changes failed."));
         return;
     }
+    // Make sure the file is empty in case of reuse.
+    m_tempFile.resize(0);
 
     QTextStream out(&m_tempFile);
     const QString fileName = m_tempFile.fileName();
@@ -663,17 +649,18 @@ void FileViewSvnPlugin::commitFiles(const QStringList& context, const QString& m
     SvnProgressDialog *progressDialog = new SvnProgressDialog(i18nc("@title:window", "SVN Commit"), SvnCommands::localRoot(context.first()), m_parentWidget);
     progressDialog->connectToProcess(&m_process);
 
-    execSvnCommand(QLatin1String("commit"), arguments,
+    execSvnCommand(QLatin1String("commit"),
+                   arguments,
                    i18nc("@info:status", "Committing SVN changes..."),
                    i18nc("@info:status", "Commit of SVN changes failed."),
                    i18nc("@info:status", "Committed SVN changes."));
 }
 
-void FileViewSvnPlugin::execSvnCommand(const QString& svnCommand,
-                                       const QStringList& arguments,
-                                       const QString& infoMsg,
-                                       const QString& errorMsg,
-                                       const QString& operationCompletedMsg)
+void FileViewSvnPlugin::execSvnCommand(const QString &svnCommand,
+                                       const QStringList &arguments,
+                                       const QString &infoMsg,
+                                       const QString &errorMsg,
+                                       const QString &operationCompletedMsg)
 {
     Q_EMIT infoMessage(infoMsg);
 
@@ -709,7 +696,7 @@ void FileViewSvnPlugin::startSvnCommandProcess()
     m_process.start(program, arguments);
 }
 
-QList<QAction*> FileViewSvnPlugin::directoryActions(const KFileItem& directory) const
+QList<QAction *> FileViewSvnPlugin::directoryActions(const KFileItem &directory) const
 {
     m_contextDir = directory.localPath();
     if (!m_contextDir.endsWith(QLatin1Char('/'))) {
@@ -735,7 +722,7 @@ QList<QAction*> FileViewSvnPlugin::directoryActions(const KFileItem& directory)
         m_revertAction->setEnabled(false);
     }
 
-    QList<QAction*> actions;
+    QList<QAction *> actions;
     actions.append(m_updateAction);
     actions.append(m_showLocalChangesAction);
     actions.append(m_commitAction);
@@ -748,7 +735,7 @@ QList<QAction*> FileViewSvnPlugin::directoryActions(const KFileItem& directory)
     return actions;
 }
 
-bool FileViewSvnPlugin::isInUnversionedDir(const KFileItem& item) const
+bool FileViewSvnPlugin::isInUnversionedDir(const KFileItem &item) const
 {
     const QString itemPath = item.localPath();
 
